---
sidebar_label: customstatistics
title: modules.statistics.customstatistics
---

## FirstLastEvent Objects

```python
class FirstLastEvent()
```

Computes the first and last events of the dataset.
Assumes that events are sorted and there is no
overlapping between events.

